###################################################
### chunk number 1: 
###################################################
library(psych)
set.seed(42)
tau <- sim.congeneric(loads=c(.8,.8,.8,.8)) #population values
tau.samp <- sim.congeneric(loads=c(.8,.8,.8,.8),N=100) # sample correlation matrix for 100 cases
round(tau.samp,2)  
tau.samp <- sim.congeneric(loads=c(.8,.8,.8,.8),N=100, short=FALSE) 
tau.samp
dim(tau.samp$observed)


###################################################
### chunk number 2: 
###################################################
cong <- sim.congeneric(N=100)
round(cong,2)


###################################################
### chunk number 3: 
###################################################
#plot.new()
m1 <- structure.diagram(c("a","b","c","d"))


###################################################
### chunk number 4: 
###################################################
set.seed(42)
gload=matrix(c(.9,.8,.7),nrow=3)
fload <- matrix(c(.9,.8,.7,rep(0,9),.7,.6,.5,
rep(0,9),.6,.5,.4),   ncol=3)
fload #echo it to see the structure
bifact <- sim.hierarchical(gload=gload,fload=fload)
round(bifact,2)


###################################################
### chunk number 5: 
###################################################
op <- par(mfrow=c(1,2))
m.bi <- omega(bifact,title="A bifactor model")
m.hi <- omega(bifact,sl=FALSE,title="A hierarchical model")
op <- par(mfrow = c(1,1))


###################################################
### chunk number 6: 
###################################################
circ <- sim.circ(16)
f2 <- fa(circ,2)
plot(f2,title="16 simulated variables in a circumplex pattern")


###################################################
### chunk number 7: 
###################################################
set.seed(42)
fx <- c(.9,.8,.7,.6)
cong1 <- sim.structure(fx)
cong1


###################################################
### chunk number 8: 
###################################################
set.seed(42)
fx  <- matrix(c(.9,.8,.7,rep(0,9),.7,.6,.5,rep(0,9),.6,.5,.4),   ncol=3)
three.fact <- sim.structure(fx)
three.fact


###################################################
### chunk number 9: 
###################################################
#plot.new()
three.fact.mod <-structure.diagram(fx)


###################################################
### chunk number 10: 
###################################################
Phi = matrix(c(1,.5,.3,.5,1,.2,.3,.2,1), ncol=3)
cor.f3 <- sim.structure(fx,Phi)
fx
Phi
cor.f3


###################################################
### chunk number 11: 
###################################################
fxs <- structure.list(9,list(F1=c(1,2,3),F2=c(4,5,6),F3=c(7,8,9)))
Phis <- phi.list(3,list(F1=c(2,3),F2=c(1,3),F3=c(1,2)))
fxs  #show the matrix
Phis #show this one as well


###################################################
### chunk number 12: 
###################################################
#plot.new()
corf3.mod <- structure.diagram(fxs,Phis)


###################################################
### chunk number 13: 
###################################################
f3.p <- Promax(fa(cor.f3$model,3))


###################################################
### chunk number 14: 
###################################################
#plot.new()
mod.f3p <- structure.diagram(f3.p,cut=.2)


###################################################
### chunk number 15: 
###################################################
set.seed(42)
fx  <- matrix(c(.9,.8,.7,rep(0,9),.7,.6,.5,rep(0,9),.6,.5,.4),   ncol=3)
fy <- c(.6,.5,.4)
Phi <- matrix(c(1,.48,.32,.4,.48,1,.32,.3,.32,.32,1,.2,.4,.3,.2,1), ncol=4)
twelveV <- sim.structure(fx,Phi, fy)$model
colnames(twelveV) <-rownames(twelveV) <- c(paste("x",1:9,sep=""),paste("y",1:3,sep=""))
round(twelveV,2)


###################################################
### chunk number 16: 
###################################################
fxs <- structure.list(9,list(X1=c(1,2,3), X2 =c(4,5,6),X3 = c(7,8,9)))
phi <- phi.list(4,list(F1=c(4),F2=c(4),F3=c(4),F4=c(1,2,3)))
fyx <- structure.list(3,list(Y=c(1,2,3)),"Y")


###################################################
### chunk number 17: 
###################################################
#plot.new()
sg3 <- structure.diagram(fxs,phi,fyx)


###################################################
### chunk number 18: 
###################################################
fxh  <- structure.list(9,list(X1=c(1:3),X2=c(4:6),X3=c(7:9),g=NULL))
fy <- structure.list(3,list(Y=c(1,2,3)))
Phi <- diag(1,5,5)
Phi[4,c(1:3)] <- letters[1:3]
Phi[5,4] <- "r"
#plot.new()
hi.mod <-structure.diagram(fxh,Phi, fy)


###################################################
### chunk number 19: 
###################################################
principal(cong1$model)
fa(cong1$model)


###################################################
### chunk number 20: 
###################################################
pc3 <- principal(bifact,3)
pa3 <- fa(bifact,3,fm="pa")
ml3 <- fa(bifact,3,fm="ml")
pc3
pa3
ml3
factor.congruence(list(pc3,pa3,ml3))


###################################################
### chunk number 21: 
###################################################
ml3p <- Promax(ml3)
ml3p


###################################################
### chunk number 22: 
###################################################
om.bi <- omega(bifact)


###################################################
### chunk number 23: 
###################################################
om.hi <- omega(bifact,sl=FALSE)


###################################################
### chunk number 24: 
###################################################
om.bi


###################################################
### chunk number 25: 
###################################################
ic <- ICLUST(bifact,title="Hierarchical cluster analysis of bifact data")


###################################################
### chunk number 26: 
###################################################
library(sem)
 mod.tau <- structure.sem(c("a","a","a","a"),labels=paste("V",1:4,sep=""))
mod.tau   #show it
sem.tau <- sem(mod.tau,cong,100)
summary(sem.tau,digits=2)


###################################################
### chunk number 27: 
###################################################
mod.cong <- structure.sem(c("a","b","c","d"),labels=paste("V",1:4,sep=""))
mod.cong  #show the model
sem.cong <- sem(mod.cong,cong,100)
summary(sem.cong,digits=2)
anova(sem.cong,sem.tau) #test the difference between the two models


###################################################
### chunk number 28: 
###################################################
mod.one <- structure.sem(letters[1:9],labels=paste("V",1:9,sep=""))
mod.one  #show the model
sem.one <- sem(mod.one,bifact,100)
summary(sem.one,digits=2)
round(residuals(sem.one),2)


###################################################
### chunk number 29: 
###################################################
f1 <- factanal(covmat=bifact,factors=1)
mod.f1 <- structure.sem(f1)
sem.f1 <- sem(mod.f1,bifact,100)
sem.f1


###################################################
### chunk number 30: 
###################################################
f3 <-fa(bifact,3)
mod.f3 <- structure.sem(f3)
sem.f3 <- sem(mod.f3,bifact,100)
summary(sem.f3,digits=2)
round(residuals(sem.f3),2)


###################################################
### chunk number 31: 
###################################################
set.seed(42)
bifact.s <- sim.hierarchical()  #create the data, use the sample correlation matrix
f3 <-fa(bifact.s,3)     #extract three factors and do an oblique rotation
mod.f3p <- structure.sem(f3.p) #create the sem model
mod.f3p   #show it 


###################################################
### chunk number 32: 
###################################################
mod.f3p.adjusted <- mod.f3p
mod.f3p.adjusted[c(1,4),2] <- NA
mod.f3p.adjusted[c(1,4),3] <- "1"
sem.f3p.adjusted <-sem(mod.f3p.adjusted,bifact.s,100) 
summary(sem.f3p.adjusted,digits=2)  


###################################################
### chunk number 33: 
###################################################
#plot.new()
mod.f3 <- structure.diagram(f3)


###################################################
### chunk number 34: 
###################################################
data(bifactor)
om.th.bi  <- omega(Thurstone,digits=3)


###################################################
### chunk number 35: 
###################################################
sem.bi <- sem(om.th.bi$model,Thurstone,213) #use the model created by omega
summary(sem.bi,digits=2)
std.coef(sem.bi,digits=2)


###################################################
### chunk number 36: 
###################################################

om.hi <- omega(Thurstone,digits=3,sl=FALSE)


###################################################
### chunk number 37: 
###################################################
sem.hi <- sem(om.hi$model,Thurstone,213)
summary(sem.hi,digits=2)
std.coef(sem.hi,digits=2)
anova(sem.hi,sem.bi)


###################################################
### chunk number 38: 
###################################################
data(bifactor)
om.holz.bi <- omega(Holzinger,4)
sem.holz.bi <- sem(om.holz.bi$model,Holzinger,355)
om.holz.hi <- omega(Holzinger,4,sl=FALSE)
sem.holz.hi <- sem(om.holz.hi$model,Holzinger,355)
anova(sem.holz.bi,sem.holz.hi)


###################################################
### chunk number 39: 
###################################################
data(bifactor)
om.sem <- omegaSem(Thurstone,n.obs=213)


###################################################
### chunk number 40: 
###################################################
omega.diagram(om.sem,sort=FALSE)


